# -*- coding: utf-8 -*-
from setuphelpers import *

r"""
Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()

PS C:\waptdev-testing\dotnet5> wapt-get list-registry "Microsoft - 5."
Using config file: C:\Program Files (x86)\wapt\wapt-get.ini
UninstallKey                           Software                                                              Version             Uninstallstring
-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
{4CD6FFC6-FA14-4016-A7A6-B7E3D6286331} Microsoft Windows Desktop Runtime - 5.0.14 (x64)                      40.56.30911         MsiExec.exe /X{4CD6FFC6-FA14-4016-A7A6-B7E3D6286331}
{61A6E3A7-F406-418A-B2A6-0606DB55B325} Microsoft .NET Host - 5.0.14 (x64)                                    40.56.30907         MsiExec.exe /X{61A6E3A7-F406-418A-B2A6-0606DB55B325}
{8D88F0E2-CE9B-4A6D-8309-FDC562195F5B} Microsoft .NET Host FX Resolver - 5.0.14 (x64)                        40.56.30907         MsiExec.exe /X{8D88F0E2-CE9B-4A6D-8309-FDC562195F5B}
{B810ACDF-1C0C-4108-9B92-12F1674FA444} Microsoft .NET Runtime - 5.0.14 (x64)                                 40.56.30907         MsiExec.exe /X{B810ACDF-1C0C-4108-9B92-12F1674FA444}
{3F927D21-88CF-4113-87C4-7F5D90ACFD5C} Microsoft Windows Desktop Runtime - 5.0.14 (x86)                      40.56.30911         MsiExec.exe /X{3F927D21-88CF-4113-87C4-7F5D90ACFD5C}
{572247F8-D39E-4F09-B2E3-886F464DB5A6} Microsoft .NET Host - 5.0.14 (x86)                                    40.56.30907         MsiExec.exe /X{572247F8-D39E-4F09-B2E3-886F464DB5A6}
{64E80A14-A4CE-4209-9E96-E3B33957FE7C} Microsoft .NET Host FX Resolver - 5.0.14 (x86)                        40.56.30907         MsiExec.exe /X{64E80A14-A4CE-4209-9E96-E3B33957FE7C}
{6c41e020-a684-4c42-95de-f3634a7747ec} Microsoft Windows Desktop Runtime - 5.0.14 (x86)                      5.0.14.30911        "C:\ProgramData\Package Cache\{6c41e020-a684-4c42-95de-f3634a7747ec}\windowsdesktop-runtime-5.0.14-win-x86.exe"  /uninstall
{B53264E4-665F-4F04-BF0C-7F9C9B7A5640} Microsoft .NET Runtime - 5.0.14 (x86)                                 40.56.30907         MsiExec.exe /X{B53264E4-665F-4F04-BF0C-7F9C9B7A5640}
{d21a4f20-968a-4b0c-bf04-a38da5f06e41} Microsoft Windows Desktop Runtime - 5.0.14 (x64)                      5.0.14.30911        "C:\ProgramData\Package Cache\{d21a4f20-968a-4b0c-bf04-a38da5f06e41}\windowsdesktop-runtime-5.0.14-win-x64.exe"  /uninstall

"""
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls
bin_contains = "windowsdesktop-runtime-"
# app_uninstallkey_x64 = "{1a728e82-3f40-4727-a130-218513758946}"
# app_uninstallkey_x86 = "{e37b6a90-60df-4744-92b5-f12059e0167d}"
app_silentflags = "/install /quiet /norestart"


def install():
    # Declaring local variables
    package_version = control.get_software_version()
    dotnet_version = package_version.split(".")[0]

    # Checking if the same or a newer version is already present
    for installed_version in installed_softwares(name="Microsoft .* Runtime - %s.*" % dotnet_version):
        if Version(installed_version["version"], 1) == Version(package_version, 1):
            if Version(installed_version["version"]) < Version(package_version):
                force = True

    # Installing the x86 software
    if not iswin64() or control.architecture == "all":
        bin_name_x86 = glob.glob("*%s*x86.exe" % bin_contains)[0]
        print("Installing: %s" % bin_name_x86)
        install_exe_if_needed(
            bin_name_x86,
            silentflags=app_silentflags,
            name="Microsoft Windows Desktop Runtime - %s.*(x86)" % dotnet_version,
            min_version="",
        )

    if iswin64():
        # Installing the x64 software
        bin_name_x64 = glob.glob("*%s*x64.exe" % bin_contains)[0]
        print("Installing: %s" % bin_name_x64)
        install_exe_if_needed(
            bin_name_x64,
            silentflags=app_silentflags,
            name="Microsoft Windows Desktop Runtime - %s.*(x64)" % dotnet_version,
            min_version="",
        )

    # Adding needed UninstallKeys as install_exe retrieve unreliable keys
    uninstallkey.clear()
    for installed_version in installed_softwares(name="Microsoft .* Runtime - %s.*" % dotnet_version):
        if Version(installed_version["version"], 1) == Version(package_version, 1):
            uninstallkey.append(installed_version["key"])